#!/usr/bin/env node
'use strict';

const path = require('path');
const fs = require('fs-extra');
const chalk = require('chalk');
const program = require('commander');
const inquirer = require('inquirer');
const packageJson = require('../package.json');

let projectName;

program
  .version(packageJson.version, '-v, --version')
  .arguments('<project-directory>')
  .usage(`${chalk.green('<project-directory>')} [options]`)
  .option('--overwrite', 'overwrite the exist path')
  .action(name => {
    projectName = name;
  })
  .parse(process.argv);

if(!projectName) {
  console.error('\nPlease specify project name!\n');
  console.log(
    `eg: ${chalk.cyan(program.name())} ${chalk.green('my-app')}\n`
  );
  process.exit(1);
}

// project init path
const root = path.resolve(projectName);
const rootExist = fs.pathExistsSync(root);

if(rootExist && !program.overwrite) {
  inquirer.prompt({
    type: 'list',
    name: 'overwrite',
    message: `Path ${chalk.yellow(root)} is exist, do you want to overwrite it?`,
    choices: [
      'Exit and Check',
      'OverWrite'
    ]
  }).then(answers => {
    const overwrite = answers.overwrite === 'OverWrite';
    if(overwrite) {
      fs.emptyDirSync(root);
      createApp();
    } else {
      process.exit(1);
    }
  });
}

function createApp() {
  fs.ensureDirSync(root);

  console.log(path.resolve('templates/*'), process.execPath)
}
